@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | Zend Engine                                                          |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1998-2013 Zend Technologies Ltd. (http://www.zend.com) |
+   | Copyright (c) 1998-2014 Zend Technologies Ltd. (http://www.zend.com) |
    +----------------------------------------------------------------------+
    | This source file is subject to version 2.00 of the Zend license,     |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -33,7 +33,7 @@
 #define ZEND_MODULE_INFO_FUNC_ARGS zend_module_entry *zend_module TSRMLS_DC
 #define ZEND_MODULE_INFO_FUNC_ARGS_PASSTHRU zend_module TSRMLS_CC
 
-#define ZEND_MODULE_API_NO 20090626
+#define ZEND_MODULE_API_NO 20100525
 #ifdef ZTS
 #define USING_ZTS 1
 #else
@@ -98,7 +98,7 @@ struct _zend_module_entry {
 	unsigned char type;
 	void *handle;
 	int module_number;
-	char *build_id;
+	const char *build_id;
 };
 
 #define MODULE_DEP_REQUIRED		1
